Description Usage Arguments Value Examples
Selector-Embedded Iterative Regression
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 | SEIR(
Y,
X,
GM = NULL,
CV = NULL,
maxStep = 10,
selector = c("L0", "L1", "MCP", "stepwise", "bess", "MARS", "SCAD", "lars", "vif",
"SES", "FBED"),
fun.selection = c("fastLm", "lm.vec"),
extraction = c("bagging-like", "1se", "min", "mean"),
X.check = c(TRUE, FALSE),
chunk.num = NULL,
file.output = TRUE,
plot.style = "CMplot",
cutOff = 0.05
)
|
Y |
Phenotypic vector with length n |
X |
n by m dataframe, matrix or big.matrix of genotype matrix |
GM |
m by 3 dataframe or matrix for SNP name, chromosome and BP |
CV |
n by t dataframe or matrix for t covariates |
maxStep |
maxStep Maximum number of iteration steps |
selector |
selector A method for Variable selection |
fun.selection |
fun.selection The core function for parameter calculation, lm.vec is more faster than fastLm |
extraction |
A method for calculating p values |
X.check |
logical |
chunk.num |
The "pieces" number of genotype matrix when considering memory size |
file.output |
output GWAS results, Manhattan and QQ plot |
plot.style |
plot.style |
cutOff |
The threshold |
List - includes the suggested SNPs, the results with normal 4-column format (SNP, chromosome, BP, p-values), the matrix of coefficients, SE, z-values, p-values, and the matrices of coefficients, SE, z-values, p-values from each iterative step
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.